@@ -1,9 +1,12 @@
 from dataclasses import dataclass
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Sekolah, JenisPendaftaran, TahunAjaran
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('pdb_id')
+@set_meta('pdb_id',
+          sekolah=Sekolah,
+          tahun_ajaran=TahunAjaran,
+          jenis_pendaftaran=JenisPendaftaran)
 @dataclass(eq=False)
 class PesertaDidikBaru(DapodikObject):
     sekolah_id: str
