@@ -1,12 +1,12 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
 @set_meta('id_role_pengguna')
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True)
 class RolePengguna(DapodikObject):
     id_role_pengguna: str
     sekolah_id: str
@@ -16,7 +16,6 @@ class RolePengguna(DapodikObject):
     dudi_id: Optional[str]
     kode_lemb_sert: Optional[str]
     pengguna_id: str
-    peran_id: 53
     sk_penugasan: Optional[str]
     tgl_sk_penugasan: Optional[str]
     approval_peran: str
@@ -28,3 +27,4 @@ class RolePengguna(DapodikObject):
     expired_date: Optional[datetime]
     last_sync: datetime
     pengguna_id_str: str
+    peran_id: Optional[int] = 53
