@@ -1,12 +1,12 @@
 from dataclasses import dataclass
 from datetime import datetime
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject
 from typing import Optional
 from dapodik.utils.decorator import set_meta
 
 
 @set_meta('sumber_listrik_id')
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True)
 class SumberListrik(DapodikObject):
     sumber_listrik_id: str
     nama: str
