@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from datetime import datetime
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
 @set_meta('sync_log_id')
-@dataclass(eq=False)
+@dataclass(eq=False, frozen=True)
 class SyncLog(DapodikObject):
     id_instalasi: str
     begin_sync: datetime
