@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, BlockGrant
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('alat_dari_blockgrant_id')
+@set_meta('alat_dari_blockgrant_id', blockgrant=BlockGrant)
 @dataclass(eq=False)
 class AlatDariBlockgrant(DapodikObject):
     blockgrant_id: str
