@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 from datetime import datetime
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Semester
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('alat_longitudinal_id')
+@set_meta('alat_longitudinal_id', semester=Semester)
 @dataclass(eq=False)
 class AlatLongitudinal(DapodikObject):
     id_alat: str
