@@ -1,11 +1,14 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Sekolah, JenisPrasarana, Ptk
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_bangunan')
+@set_meta('id_bangunan',
+          jenis_prasarana=JenisPrasarana,
+          sekolah=Sekolah,
+          ptk=Ptk)
 @dataclass(eq=False)
 class Bangunan(DapodikObject):
     id_bangunan: str
@@ -55,3 +58,8 @@ class Bangunan(DapodikObject):
     id_tanah_str: str
     sekolah_id_str: str
     vld_count: int
+
+    @property
+    def kepemilikan_sarpras(self):
+        # TODO API
+        return self.kepemilikan_sarpras_id
