@@ -1,11 +1,14 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Sekolah, JenisPrasarana, Bangunan
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_ruang')
+@set_meta('id_ruang',
+          jenis_prasarana=JenisPrasarana,
+          sekolah=Sekolah,
+          bangunan=Bangunan)
 @dataclass(eq=False)
 class Ruang(DapodikObject):
     id_ruang: str
