@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Semester, Ruang
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('ruang_longitudinal_id')
+@set_meta('ruang_longitudinal_id', semester=Semester, ruang=Ruang)
 @dataclass(eq=False)
 class RuangLongitudinal(DapodikObject):
     id_ruang: str
