@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Sekolah, JenisPrasarana
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_tanah')
+@set_meta('id_tanah', jenis_prasarana=JenisPrasarana, sekolah=Sekolah)
 @dataclass(eq=False)
 class Tanah(DapodikObject):
     id_tanah: str
@@ -40,3 +40,8 @@ class Tanah(DapodikObject):
     jenis_prasarana_id_str: str
     sekolah_id_str: str
     vld_count: int
+
+    @property
+    def kepemilikan_sarpras(self):
+        # TODO API
+        return self.kepemilikan_sarpras_id
