@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Sekolah, SumberDanaSekolah
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('blockgrant_id')
+@set_meta('blockgrant_id', sekolah=Sekolah, sumber_dana=SumberDanaSekolah)
 @dataclass(eq=False)
 class BlockGrant(DapodikObject):
     blockgrant_id: str
@@ -26,4 +26,8 @@ class BlockGrant(DapodikObject):
     sekolah_id_str: str
     jenis_bantuan_id_str: str
     sumber_dana_id_str: str
-    blockgrant_id: str
+
+    @property
+    def jenis_bantuan(self):
+        # TODO API
+        return self.jenis_bantuan_id
