@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 from datetime import datetime
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Sekolah
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_panitia')
+@set_meta('id_panitia', sekolah=Sekolah)
 @dataclass(eq=False)
 class Kepanitiaan(DapodikObject):
     id_panitia: str
@@ -29,3 +29,8 @@ class Kepanitiaan(DapodikObject):
     updater_id: str
     sekolah_id_str: str
     id_jns_panitia_str: str
+
+    @property
+    def jns_panitia(self):
+        # TODO API
+        return self.id_jns_panitia
