@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
+from dapodik import DapodikObject, Sekolah
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_panitia')
+@set_meta('id_pi', sekolah=Sekolah)
 @dataclass(eq=False)
 class ProgramInklusi(DapodikObject):
     id_pi: str
