@@ -1,13 +1,14 @@
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
-from dapodik.base import DapodikObject
-from dapodik.rest import SumberAir
+from dapodik import DapodikObject, SumberAir, Sekolah, Semester
 from dapodik.utils.decorator import set_meta
-from .sekolah import Sekolah
 
 
-@set_meta('sanitasi_id')
+@set_meta('sanitasi_id',
+          sekolah=Sekolah,
+          semester=Semester,
+          sumber_air=SumberAir)
 @dataclass(eq=False)
 class Sanitasi(DapodikObject):
     sekolah_id: str
@@ -90,11 +91,6 @@ class Sanitasi(DapodikObject):
     sanitasi_id: str
 
     @property
-    @Sekolah.getter
-    def sekolah(self):
-        return self.sekolah_id
-
-    @property
-    @SumberAir.getter
-    def sumber_air(self):
+    def sumber_air_minum(self):
+        # TODO API
         return self.sumber_air_minum_id
