@@ -1,10 +1,18 @@
 from dataclasses import dataclass
 from datetime import datetime
-from dapodik.base import DapodikObject
+from typing import Optional
+from dapodik import (DapodikObject, WaktuPenyelenggaraan, AksesInternet,
+                     Sekolah, Semester, SumberListrik)
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('sekolah_longitudinal_id')
+@set_meta('sekolah_longitudinal_id',
+          sekolah=Sekolah,
+          semester=Semester,
+          waktu_penyelenggaraan=WaktuPenyelenggaraan,
+          sumber_listrik=SumberListrik,
+          akses_internet=AksesInternet,
+          akses_internet_2=AksesInternet.with_id('akses_internet_2_id'))
 @dataclass(eq=False)
 class SekolahLongitudinal(DapodikObject):
     sekolah_id: str
@@ -24,7 +32,7 @@ class SekolahLongitudinal(DapodikObject):
     daya_listrik: str
     akses_internet_id: int
     akses_internet_2_id: int
-    blob_id: str
+    blob_id: Optional[str]
     create_date: datetime
     last_update: datetime
     soft_delete: str
@@ -33,3 +41,8 @@ class SekolahLongitudinal(DapodikObject):
     waktu_penyelenggaraan_id_str: str
     sekolah_id_str: str
     sekolah_longitudinal_id: str
+
+    @property
+    def sertifikasi_iso(self):
+        # TODO API
+        return self.sertifikasi_iso_id
