@@ -1,10 +1,24 @@
 from dataclasses import dataclass
 from datetime import datetime
-from dapodik.base import DapodikObject
+from dapodik import (
+    Sekolah,
+    DapodikObject,
+    KategoriTk,
+    KlasifikasiLembaga,
+    SumberDanaSekolah,
+    FasilitasLayanan,
+    LembagaPengangkat,
+)
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('kategori_tk_id')
+@set_meta('sekolah_id',
+          sekolah=Sekolah,
+          kategori_tk=KategoriTk,
+          klasifikasi_lembaga=KlasifikasiLembaga,
+          sumber_dana_sekolah=SumberDanaSekolah,
+          fasilitas_layanan=FasilitasLayanan,
+          lembaga_pengangkat=LembagaPengangkat)
 @dataclass(eq=False)
 class SekolahPaud(DapodikObject):
     sekolah_id: str
@@ -37,3 +51,8 @@ class SekolahPaud(DapodikObject):
     soft_delete: str
     last_sync: datetime
     updater_id: str
+
+    @property
+    def bentuk_lembaga(self):
+        # TODO API
+        return self.bentuk_lembaga_id
